@@ -2,7 +2,7 @@
  * descriptor.c: descriptors functions
  *----------------------------------------------------------------------------
  * (c)2001-2002 VideoLAN
- * $Id: descriptor.c,v 1.5 2002/05/08 14:56:28 bozo Exp $
+ * $Id: descriptor.c,v 1.6 2002/10/07 14:15:14 sam Exp $
  *
  * Authors: Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
  *
@@ -30,6 +30,12 @@
 #include <stdlib.h>
 #include <string.h>
 
+#if defined(HAVE_INTTYPES_H)
+#include <inttypes.h>
+#elif defined(HAVE_STDINT_H)
+#include <stdint.h>
+#endif
+
 #include "dvbpsi.h"
 #include "descriptor.h"
 
