@@ -2,7 +2,7 @@
  * pat.c: PAT decoder/generator
  *----------------------------------------------------------------------------
  * (c)2001-2002 VideoLAN
- * $Id: pat.c 187 2009-11-18 07:26:10Z md $
+ * $Id: pat.c,v 1.4 2002/10/10 09:27:02 sam Exp $
  *
  * Authors: Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
  *
@@ -108,8 +108,6 @@ void dvbpsi_DetachPAT(dvbpsi_handle h_dvbpsi)
   }
 
   free(h_dvbpsi->p_private_decoder);
-  if(h_dvbpsi->p_current_section)
-    dvbpsi_DeletePSISections(h_dvbpsi->p_current_section);
   free(h_dvbpsi);
 }
 
@@ -265,10 +263,19 @@ void dvbpsi_GatherPATSections(dvbpsi_decoder_t* p_decoder,
       else
       {
         if(    (p_pat_decoder->b_current_valid)
-            && (p_pat_decoder->current_pat.i_version == p_section->i_version)
-            && (p_pat_decoder->current_pat.b_current_next ==
-                                           p_section->b_current_next))
+            && (p_pat_decoder->current_pat.i_version == p_section->i_version))
         {
+          /* Signal a new PAT if the previous one wasn't active */
+          if(    (!p_pat_decoder->current_pat.b_current_next)
+              && (p_section->b_current_next))
+          {
+            dvbpsi_pat_t* p_pat = (dvbpsi_pat_t*)malloc(sizeof(dvbpsi_pat_t));
+
+            p_pat_decoder->current_pat.b_current_next = 1;
+            *p_pat = p_pat_decoder->current_pat;
+            p_pat_decoder->pf_callback(p_pat_decoder->p_cb_data, p_pat);
+          }
+
           /* Don't decode since this version is already decoded */
           b_append = 0;
         }
@@ -343,7 +350,7 @@ void dvbpsi_GatherPATSections(dvbpsi_decoder_t* p_decoder,
       /* Chain the sections */
       if(p_pat_decoder->i_last_section_number)
       {
-        for(i = 0; (int)i <= p_pat_decoder->i_last_section_number - 1; i++)
+        for(i = 0; i <= p_pat_decoder->i_last_section_number - 1; i++)
           p_pat_decoder->ap_sections[i]->p_next =
                                         p_pat_decoder->ap_sections[i + 1];
       }
